---
layout: "vault"
page_title: "Vault: vault_identity_group data source"
sidebar_current: "docs-vault-datasource-identity-group"
description: |-
  Lookup an Identity Group from Vault
---

# vault\_identity\_group

Lookup an Identity Group for Vault. The Identity secrets engine is the identity management solution
for Vault. It internally maintains the clients who are recognized by Vault.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
data "vault_identity_group" "group" {
  group_name = "user"
}
```

## Argument Reference

The following arguments are supported:

* `group_name` - (Optional) Name of the group.

* `group_id` - (Optional) ID of the group.

* `alias_id` - (Optional)  ID of the alias.

* `alias_name` - (Optional)  Name of the alias. This should be supplied in conjunction with
  `alias_mount_accessor`.

* `alias_mount_accessor` - (Optional) Accessor of the mount to which the alias belongs to.
  This should be supplied in conjunction with `alias_name`.

The lookup criteria can be `group_name`, `group_id`, `alias_id`, or a combination of
`alias_name` and `alias_mount_accessor`.

## Required Vault Capabilities

Use of this resource requires the `create` capability on `/identity/lookup/group`.

## Attributes Reference

The following attributes are exported:

* `data_json` - A string containing the full data payload retrieved from
  Vault, serialized in JSON format.

* `creation_time` - Creation timestamp of the group

* `last_update_time` - Last updated time of the group

* `member_entity_ids` - List of Entity IDs which are members of this group

* `member_group_ids` - List of Group IDs which are members of this group

* `metadata` - Arbitrary metadata

* `modify_index` - Modify index of the group

* `namespace_id` - Namespace of which the group is part of

* `parent_group_ids` - List of Group IDs which are parents of this group.

* `policies` - List of policies attached to the group

* `type` - Type of group

* `alias_canonical_id` - Canonical ID of the Alias

* `alias_creation_time` - Creation time of the Alias

* `alias_last_update_time` - Last update time of the alias

* `alias_merged_from_canonical_ids` - List of canonical IDs merged with this alias

* `alias_metadata` - Arbitrary metadata

* `alias_mount_path` - Authentication mount path which this alias belongs to

* `alias_mount_type` - Authentication mount type which this alias belongs to
