---
layout: "vault"
page_title: "Vault: vault_ad_secret_backend_library resource"
sidebar_current: "docs-vault-resource-ad-secret-backend-library"
description: |-
  Creates a library on the Active Directory Secret Backend for Vault.
---

# vault\ad\_secret\_backend\_library

Creates a library on an Active Directory Secret Backend for Vault. Libraries create
a pool of existing Active Directory service accounts which can be checked out
by users.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_ad_secret_backend" "config" {
    backend = "ad"
    binddn = "CN=Administrator,CN=Users,DC=corp,DC=example,DC=net"
    bindpass = "SuperSecretPassw0rd"
    url = "ldaps://ad"
    insecure_tls = "true"
    userdn = "CN=Users,DC=corp,DC=example,DC=net"
}

resource "vault_ad_secret_library" "qa" {
    backend = vault_ad_secret_backend.config.backend
    name = "qa"
    service_account_names = ["Bob", "Mary"]
    ttl = 60
    disable_check_in_enforcement = true
    max_ttl = 120
}
```

## Argument Reference

The following arguments are supported:

* `backend` - (Required) The path the AD secret backend is mounted at,
  with no leading or trailing `/`s.

* `name` - (Required) The name to identify this set of service accounts.
  Must be unique within the backend.

* `service_account_names` - (Required) Specifies the slice of service accounts mapped to this set.

* `ttl` - (Optional) The password time-to-live in seconds. Defaults to the configuration
  ttl if not provided.

* `max_ttl` - (Optional) The maximum password time-to-live in seconds. Defaults to the configuration
    max_ttl if not provided.

## Import

AD secret backend libraries can be imported using the `path`, e.g.

```
$ terraform import vault_ad_secret_backend_library.role ad/library/bob
```
