---
layout: "vault"
page_title: "Vault: vault_ad_secret_backend_role resource"
sidebar_current: "docs-vault-resource-ad-secret-backend-role"
description: |-
  Creates a role on the Active Directory Secret Backend for Vault.
---

# vault\ad\_secret\_backend\_role

Creates a role on an Active Directory Secret Backend for Vault. Roles are
used to map credentials to existing Active Directory service accounts.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_ad_secret_backend" "config" {
    backend = "ad"
    binddn = "CN=Administrator,CN=Users,DC=corp,DC=example,DC=net"
    bindpass = "SuperSecretPassw0rd"
    url = "ldaps://ad"
    insecure_tls = "true"
    userdn = "CN=Users,DC=corp,DC=example,DC=net"
}

resource "vault_ad_secret_role" "role" {
    backend = vault_ad_secret_backend.config.backend
    role = "bob"
    service_account_name = "Bob"
    ttl = 60
}
```

## Argument Reference

The following arguments are supported:

* `backend` - (Required) The path the AD secret backend is mounted at,
  with no leading or trailing `/`s.

* `role` - (Required) The name to identify this role within the backend.
  Must be unique within the backend.

* `service_account_name` - (Required) Specifies the name of the Active Directory service
account mapped to this role.

* `ttl` - (Optional) The password time-to-live in seconds. Defaults to the configuration
  ttl if not provided.

## Attributes Reference

* `last_vault_rotation` - Timestamp of the last password rotation by Vault.

* `password_last_set` - Timestamp of the last password set by Vault.

## Import

AD secret backend roles can be imported using the `path`, e.g.

```
$ terraform import vault_ad_secret_backend_role.role ad/roles/bob
```
