---
layout: "vault"
page_title: "Vault: vault_nomad_secret_role resource"
sidebar_current: "docs-vault-resource-nomad-secret-role"
description: |-
  Creates a Nomad role.
---

# vault\_nomad\_secret\_role

Creates a Vault role for a Nomad token. This role configures how generated tokens 
will function.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_nomad_secret_backend" "config" {
	backend = "nomad"
	description = "test description"
	default_lease_ttl_seconds = "3600"
	max_lease_ttl_seconds = "7200"
	address = "https://127.0.0.1:4646"
	token = "ae20ceaa-..."
}

resource "vault_nomad_secret_role" "test" {
    backend = vault_nomad_secret_backend.config.backend
    role = "test"
    type = "client"
	policies = ["readonly"]
}
```

## Argument Reference

The following arguments are supported:

* `backend` - (Optional) The unique path this backend should be mounted at. Must
not begin or end with a `/`. Defaults to `nomad`.

* `role` - (Required) The name to identify this role within the backend.
Must be unique within the backend.

* `global` - (Optional) Specifies if the generated token should be global. Defaults to 
false.

* `policies` - (Optional) List of policies attached to the generated token. This setting is only used 
when `type` is 'client'.
  
* `type` - (Optional)  Specifies the type of token to create when using this role. Valid 
settings are 'client' and 'management'. Defaults to 'client'.



## Attributes Reference

No additional attributes are exported by this resource.

## Import

Nomad secret role can be imported using the `backend`, e.g.

```
$ terraform import vault_nomad_secret_role.bob nomad/role/bob
```
