---
layout: "vault"
page_title: "Vault: vault_pki_secret_backend_cert resource"
sidebar_current: "docs-vault-resource-pki-secret-backend-cert"
description: |-
  Generate an PKI certificate.
---

# vault\_pki\_secret\_backend\_cert

Generates a certificate from the PKI Secret Backend.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_pki_secret_backend_cert" "app" {
  depends_on = [ "vault_pki_secret_backend_role.admin" ]

  backend = "${vault_pki_secret_backend.intermediate.path}"
  name = "${vault_pki_secret_backend_role.test.name}"

  common_name = "app.my.domain"
}
```

## Argument Reference

The following arguments are supported:

* `backend` - (Required) The PKI secret backend the resource belongs to.

* `name` - (Required) Name of the role to create the certificate against

* `common_name` - (Required) CN of certificate to create

* `alt_names` - (Optional) List of alternative names

* `ip_sans` - (Optional) List of alternative IPs

* `uri_sans` - (Optional) List of alternative URIs

* `other_sans` - (Optional) List of other SANs

* `ttl` - (Optional) Time to live

* `format` - (Optional) The format of data

* `private_key_format` - (Optional) The private key format

* `exclude_cn_from_sans` - (Optional) Flag to exclude CN from SANs

* `min_seconds_remaining` - (Optional) Generate a new certificate when the expiration is within this number of seconds, default is 604800 (7 days)

* `auto_renew` - (Optional) If set to `true`, certs will be renewed if the expiration is within `min_seconds_remaining`. Default `false`

## Attributes Reference

In addition to the fields above, the following attributes are exported:

* `certificate` - The certificate

* `issuing_ca` - The issuing CA

* `ca_chain` - The CA chain

* `private_key` - The private key

* `private_key_type` - The private key type

* `serial_number` - The serial number

* `expiration` - The expiration date of the certificate in unix epoch format
